@@ -29,6 +29,7 @@ import click
 import csv
 import os
 import os.path
+import pkg_resources
 import shodan
 import shodan.helpers as helpers
 import threading
@@ -125,6 +126,31 @@ def convert(input, format):
         click.echo(click.style('\rSuccessfully created new file: {}'.format(filename), fg='green'))
 
 
+@main.command(name='domain')
+@click.argument('domain', metavar='<domain>')
+def domain_info(domain):
+    """View all available information for a domain"""
+    key = get_api_key()
+    api = shodan.Shodan(key)
+
+    try:
+        info = api.dns.domain_info(domain)
+    except shodan.APIError as e:
+        raise click.ClickException(e.value)
+
+    click.secho(info['domain'].upper(), fg='green')
+
+    click.echo('')
+    for record in info['data']:
+        click.echo(
+            '{:32}  {:14}  {}'.format(
+                click.style(record['subdomain'], fg='cyan'),
+                click.style(record['type'], fg='yellow'),
+                record['value']
+            )
+        )
+
+
 @main.command()
 @click.argument('key', metavar='<api key>')
 def init(key):
@@ -179,9 +205,10 @@ def count(query):
 
 @main.command()
 @click.option('--limit', help='The number of results you want to download. -1 to download all the data possible.', default=1000, type=int)
+@click.option('--skip', help='The number of results to skip when starting the download.', default=0, type=int)
 @click.argument('filename', metavar='<filename>')
 @click.argument('query', metavar='<search query>', nargs=-1)
-def download(limit, filename, query):
+def download(limit, skip, filename, query):
     """Download search results and save them in a compressed JSON file."""
     key = get_api_key()
 
@@ -221,11 +248,15 @@ def download(limit, filename, query):
     # A limit of -1 means that we should download all the data
     if limit <= 0:
         limit = total
+    
+        # Adjust the total number of results we should expect to download if the user is skipping results
+        if skip > 0:
+            limit -= skip
 
     with helpers.open_file(filename, 'w') as fout:
         count = 0
         try:
-            cursor = api.search_cursor(query, minify=False)
+            cursor = api.search_cursor(query, minify=False, skip=skip)
             with click.progressbar(cursor, length=limit) as bar:
                 for banner in bar:
                     helpers.write_banner(fout, banner)
@@ -728,5 +759,11 @@ def radar():
         raise click.ClickException(u'{}'.format(e))
 
 
+@main.command()
+def version():
+    """Print version of this tool."""
+    print(pkg_resources.get_distribution("shodan").version)
+
+
 if __name__ == '__main__':
     main()
