@@ -64,6 +64,16 @@ class Shodan:
             """
             return self.parent._request('/shodan/data/{}'.format(dataset), {})
 
+    class Dns:
+
+        def __init__(self, parent):
+            self.parent = parent
+
+        def domain_info(self, domain):
+            """Grab the DNS information for a domain.
+            """
+            return self.parent._request('/dns/domain/{}'.format(domain), {})
+
     class Tools:
 
         def __init__(self, parent):
@@ -182,6 +192,7 @@ class Shodan:
         self.base_url = 'https://api.shodan.io'
         self.base_exploits_url = 'https://exploits.shodan.io'
         self.data = self.Data(self)
+        self.dns = self.Dns(self)
         self.exploits = self.Exploits(self)
         self.labs = self.Labs(self)
         self.org = self.Organization(self)
@@ -190,6 +201,7 @@ class Shodan:
         self._session = requests.Session()
         if proxies:
             self._session.proxies.update(proxies)
+            self._session.trust_env = False
 
     def _request(self, function, params, service='shodan', method='get'):
         """General-purpose function to create web requests to SHODAN.
@@ -418,7 +430,7 @@ class Shodan:
 
         return self._request('/shodan/host/search', args)
 
-    def search_cursor(self, query, minify=True, retries=5):
+    def search_cursor(self, query, minify=True, retries=5, skip=0):
         """Search the SHODAN database.
 
         This method returns an iterator that can directly be in a loop. Use it when you want to loop over
@@ -431,17 +443,28 @@ class Shodan:
         :param minify: (optional) Whether to minify the banner and only return the important data
         :type minify: bool
         :param retries: (optional) How often to retry the search in case it times out
-        :type minify: int
+        :type retries: int
+        :param skip: (optional) Number of results to skip
+        :type skip: int
 
         :returns: A search cursor that can be used as an iterator/ generator.
         """
         page = 1
         tries = 0
+
+        # Placeholder results object to make the while loop below easier
         results = {
-            'matches': [],
+            'matches': [True],
             'total': None,
         }
-        while page == 1 or results['matches']:
+
+        # Convert the number of skipped records into a page number
+        if skip > 0:
+            # Each page returns 100 results so find the nearest page that we want
+            # the cursor to skip to.
+            page += int(skip / 100)
+
+        while results['matches']:
             try:
                 results = self.search(query, minify=minify, page=page)
                 for banner in results['matches']:
@@ -454,7 +477,7 @@ class Shodan:
             except Exception:
                 # We've retried several times but it keeps failing, so lets error out
                 if tries >= retries:
-                    break
+                    raise APIError('Retry limit reached ({:d})'.format(retries))
 
                 tries += 1
                 time.sleep(1.0)  # wait 1 second if the search errored out for some reason
@@ -586,3 +609,11 @@ class Shodan:
     def disable_alert_trigger(self, aid, trigger):
         """Disable the given trigger on the alert."""
         return self._request('/shodan/alert/{}/trigger/{}'.format(aid, trigger), {}, method='delete')
+
+    def ignore_alert_trigger_notification(self, aid, trigger, ip, port):
+        """Ignore trigger notifications for the provided IP and port."""
+        return self._request('/shodan/alert/{}/trigger/{}/ignore/{}:{}'.format(aid, trigger, ip, port), {}, method='put')
+
+    def unignore_alert_trigger_notification(self, aid, trigger, ip, port):
+        """Re-enable trigger notifications for the provided IP and port"""
+        return self._request('/shodan/alert/{}/trigger/{}/ignore/{}:{}'.format(aid, trigger, ip, port), {}, method='delete')
